import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def indent(levels) -> None: ...
def keyconfig_export_as_data(wm, kc, filepath, *, all_keymaps=False) -> None: ...
def keyconfig_import_from_data(
    name, keyconfig_data, *, keyconfig_version=(0, 0, 0)
) -> None: ...
def keyconfig_init_from_data(kc, keyconfig_data) -> None: ...
def keyconfig_merge(kc1, kc2) -> None:
    """note: kc1 takes priority over kc2"""

def keymap_init_from_data(km, km_items, is_modal=False) -> None: ...
def kmi_args_as_data(kmi) -> None: ...
def repr_f32(f) -> None: ...
def round_float_32(f) -> None: ...
